import ms from 'milliseconds';
import { readCookie, writeCookie, deleteCookie } from './cookie';
import { getLocalStorageItem, deleteLocalStorageItem } from './ls';

export const createTokenWriter = (name = 'token') => {
  const writeToken = token => {
    writeCookie(name, token, { maxAge: ms.days(180), secure: true });
  };

  const readToken = () => {
    const valueFromLS = getLocalStorageItem(name);
    const valueFromCookie = readCookie(name);
    if (valueFromLS && valueFromLS !== valueFromCookie) {
      writeToken(valueFromLS);
      deleteLocalStorageItem(name);
    }
    return valueFromCookie;
  };

  const clearToken = () => deleteCookie(name);

  return {
    writeToken,
    readToken,
    clearToken
  };
};